@@ -19,6 +19,12 @@ from .persistent_data_manager import PersistentDataManager
 from .Extension import Extension, global_extensions
 from .openai_func import TextGenerator
 from .command_func import CommandManager, cmd
+try:
+    import nonebot_plugin_htmlrender
+    from .text_func import text_to_img
+except:
+    config.ENABLE_MSG_TO_IMG = False
+    config.ENABLE_COMMAND_TO_IMG = False
 
 permission_check_func:Callable[[Matcher, MessageEvent, Bot, str, str], Awaitable[Tuple[bool,str]]] = None
 is_progress:bool = False
@@ -90,16 +96,18 @@ async def handler(matcher_:Matcher, event: MessageEvent, bot:Bot) -> None:
     else:
         logger.info("未知消息来源: " + event.get_session_id())
         return
+    
+    chat_text, wake_up = await gen_chat_text(event=event, bot=bot)
 
     # 进行消息响应
     await do_msg_response(
         event.get_user_id(),
-        await gen_chat_text(event=event, bot=bot),
-        event.is_tome(),
+        chat_text,
+        event.is_tome() or wake_up,
         matcher,
         chat_type,
         chat_key,
-        sender_name
+        sender_name,
     )
 
 
@@ -197,10 +205,14 @@ async def _(matcher_:Matcher, event: MessageEvent, bot:Bot, arg: Message = Comma
     )
 
     if res:
-        if res.get('msg'):
-            await identity.send(res.get('msg'))  # 如果有返回消息则发送
+        if res.get('msg'):     # 如果有返回消息则发送
+            if config.ENABLE_COMMAND_TO_IMG:
+                img = await text_to_img(res.get('msg'))
+                await identity.send(MessageSegment.image(img))
+            else:
+                await identity.send(res.get('msg'))  
         elif res.get('error'):
-            await identity.finish(f"执行命令时出现错误: {res.get('error')}")  # 如果有返回错误则发送
+            await identity.finish(f"执行命令时出现错误: {res.get('error')}")  # 如果有返回错误则发送s
 
     else:
         await identity.finish("输入的命令好像有点问题呢... 请检查下再试试吧！ ╮(>_<)╭")
@@ -211,257 +223,6 @@ async def _(matcher_:Matcher, event: MessageEvent, bot:Bot, arg: Message = Comma
         PersistentDataManager.instance.save_to_file()  # 保存数据
     return
 
-    # 以下为旧的人格设定指令处理
-    if not raw_cmd:
-        await identity.finish((
-            f"会话: {chat_key} [{'启用' if chat.is_enable else '禁用'}]\n"
-            f"当前可用人格预设有:\n"
-            f"{presets_show_text}\n"
-            f"=======================\n"
-            f"+ 使用预设: rg 设定 <预设名>\n"
-            f"+ 查询预设: rg 查询 <预设名>\n"
-            f"+ 更新预设: rg 更新 <预设名> <人格信息>\n"
-            f"+ 添加预设: rg 添加 <预设名> <人格信息>\n"
-            f"Tip: <人格信息> 是一段第三人称的人设说明(不超过200字, 不包含空格)\n"
-        ))
-
-    elif raw_cmd in ['admin']:
-        # if str(event.user_id) not in config.ADMIN_USERID:
-        #     await identity.finish("您没有权限执行此操作！")
-        await identity.finish((
-            f"当前可用人格预设有:\n"
-            f"{presets_show_text}\n"
-            f"=======================\n"
-            f"+ 使用预设: rg <设定/set> <预设名> <-all?>\n"
-            f"+ 查询预设: rg <查询/query> <预设名>\n"
-            f"+ 更新预设: rg <更新/update> <预设名> <人格信息>\n"
-            f"+ 添加预设: rg <添加/new> <预设名> <人格信息>\n"
-            f"+ 删除预设(管理): rg 删除 <预设名>\n"
-            f"+ 锁定预设(管理): rg 锁定 <预设名>\n"
-            f"+ 解锁预设(管理): rg 解锁 <预设名>\n"
-            f"+ 开启会话(管理): rg <开启/on> <-all?>\n"
-            f"+ 停止会话(管理): rg <关闭/off> <-all?>\n"
-            f"+ 查询会话(管理): rg <会话/chats>\n"
-            f"+ 重置会话(管理): rg <重置/reset> <-all?>\n"
-            f"+ 查询记忆(管理): rg <记忆/memory>\n"
-            f"+ 扩展信息(管理): rg <扩展/ext>\n"
-            f"Tip: <人格信息> 是一段第三人称的人设说明(建议不超过200字)\n"
-        ))
-
-    elif (raw_cmd.split(' ')[0] in ["设定", "set"]) and len(raw_cmd.split(' ')) >= 2:
-        target_preset_key = raw_cmd.split(' ')[1]
-        if target_preset_key not in chat_presets_dict:
-            # 如果预设不存在，进行逐一进行字符匹配，选择最相似的预设
-            target_preset_key = difflib.get_close_matches(target_preset_key, chat_presets_dict.keys(), n=1, cutoff=0.3)
-            if len(target_preset_key) == 0:
-                await identity.finish("找不到匹配的人格预设! 是不是手滑了呢？(；′⌒`)")
-            else:
-                target_preset_key = target_preset_key[0]
-                await identity.send(f"预设不存在! 已为您匹配最相似的预设: {target_preset_key} v(￣▽￣)v")
-
-        if len(raw_cmd.split(' ')) > 2 and raw_cmd.split(' ')[2] == '-all':
-            # if str(event.user_id) not in config.ADMIN_USERID:
-            #     await identity.finish("您没有权限执行此操作！")
-            for chat_key in global_chat_dict.keys():
-                global_chat_dict[chat_key].change_presettings(target_preset_key)
-            await identity.send(f"应用预设: {target_preset_key} (￣▽￣)-ok! (所有会话)")
-        else:
-            chat.change_presettings(target_preset_key)
-            await identity.send(f"应用预设: {target_preset_key} (￣▽￣)-ok!")
-        is_progress = True
-
-    elif (raw_cmd.split(' ')[0] in ["查询", "query"]) and len(raw_cmd.split(' ')) >= 2:
-        target_preset_key = raw_cmd.split(' ')[1]
-        if target_preset_key not in chat_presets_dict:
-            # 如果预设不存在，进行逐一进行字符匹配，选择最相似的预设
-            target_preset_key = difflib.get_close_matches(target_preset_key, chat_presets_dict.keys(), n=1, cutoff=0.3)
-            if len(target_preset_key) == 0:
-                await identity.finish("找不到匹配的人格预设! 是不是手滑了呢？(；′⌒`)")
-            else:
-                target_preset_key = target_preset_key[0]
-                await identity.send(f"预设不存在! 帮您匹配最相似的预设: {target_preset_key} v(￣▽￣)v")
-        is_progress = True
-        await identity.finish(f"预设: {target_preset_key} | 人设信息:\n    {chat_presets_dict[target_preset_key].bot_self_introl}")
-
-    elif (raw_cmd.split(' ')[0] in ["更新", "update", "edit"]) and len(raw_cmd.split(' ')) >= 3:
-        target_preset_key = raw_cmd.split(' ')[1]
-        if target_preset_key not in chat_presets_dict:
-            await identity.finish("找不到匹配的人格预设! 是不是手滑了呢？(；′⌒`)")
-        if chat_presets_dict[target_preset_key].is_locked and (str(event.user_id) not in config.ADMIN_USERID):
-            await identity.finish("该预设被神秘力量锁定了! 不能编辑呢 (＠_＠;)")
-        chat_presets_dict[target_preset_key].bot_self_introl = raw_cmd.split(' ', 2)[2]
-        is_progress = True
-        await identity.send(f"更新预设: {target_preset_key} 成功! (￣▽￣)")
-
-    elif (raw_cmd.split(' ')[0] in ["添加", "new"]) and len(raw_cmd.split(' ')) >= 3:
-        target_preset_key = raw_cmd.split(' ')[1]
-        introl = raw_cmd.split(' ', 2)[2]
-        if target_preset_key in chat_presets_dict:
-            await identity.finish("预设已存在! 请检查后重试!")
-        PersistentDataManager.instance.add_preset(chat_key=chat_key, preset_key=target_preset_key, bot_self_introl=introl)
-        is_progress = True
-        await identity.send(f"添加预设: {target_preset_key} 成功! (￣▽￣)")
-
-    elif (raw_cmd.split(' ')[0] in ["删除", "del", "delete"]) and len(raw_cmd.split(' ')) == 2:
-        target_preset_key = raw_cmd.split(' ')[1]
-        # if str(event.user_id) not in config.ADMIN_USERID:
-        #     await identity.finish("对不起！你没有权限进行此操作 ＞﹏＜")
-        if target_preset_key not in chat_presets_dict:
-            await identity.finish("找不到匹配的人格预设! 是不是手滑了呢？(；′⌒`)")
-        del chat_presets_dict[target_preset_key]
-        is_progress = True
-        await identity.send(f"删除预设: {target_preset_key} 成功! (￣▽￣)")
-
-    elif (raw_cmd.split(' ')[0] in ["锁定", "lock"]) and len(raw_cmd.split(' ')) == 2:
-        target_preset_key = raw_cmd.split(' ')[1]
-        # if str(event.user_id) not in config.ADMIN_USERID:
-        #     await identity.finish("对不起！你没有权限进行此操作 ＞﹏＜")
-        if target_preset_key not in chat_presets_dict:
-            await identity.finish("找不到匹配的人格预设! 是不是手滑了呢？(；′⌒`)")
-        chat_presets_dict[target_preset_key].is_locked = True
-        is_progress = True
-        await identity.send(f"锁定预设: {target_preset_key} 成功! (￣▽￣)")
-
-    elif (raw_cmd.split(' ')[0] in ["解锁", "unlock"]) and len(raw_cmd.split(' ')) == 2:
-        target_preset_key = raw_cmd.split(' ')[1]
-        # if str(event.user_id) not in config.ADMIN_USERID:
-        #     await identity.finish("对不起！你没有权限进行此操作 ＞﹏＜")
-        if target_preset_key not in chat_presets_dict:
-            await identity.finish("找不到匹配的人格预设! 是不是手滑了呢？(；′⌒`)")
-        chat_presets_dict[target_preset_key].is_locked = False
-        is_progress = True
-        await identity.send(f"解锁预设: {target_preset_key} 成功! (￣▽￣)")
-
-    elif raw_cmd in ["扩展", "ext"]:
-        # if str(event.user_id) not in config.ADMIN_USERID:
-        #     await identity.finish("对不起！你没有权限进行此操作 ＞﹏＜")
-        # 查询所有扩展插件并生成汇报信息
-        ext_info = ''
-        for ext in global_extensions.values():
-            ext_info += f"  {ext.generate_short_description()}"
-        await identity.finish((
-            f"当前已加载的扩展模块:\n{ext_info}"
-        ))
-
-    elif raw_cmd in ["开启", "on"]:
-        # if event.sender.role == 'member' and str(event.user_id) not in config.ADMIN_USERID:
-        #     await identity.finish("对不起！你没有权限进行此操作 ＞﹏＜")
-        chat.toggle_chat(enabled=True)
-        await identity.finish("已开启会话! <(￣▽￣)>")
-
-    elif (raw_cmd.split(' ')[0] in ["开启", "on"]) and len(raw_cmd.split(' ')) == 2:
-        # if str(event.user_id) not in config.ADMIN_USERID:
-        #     await identity.finish("对不起！你没有权限进行此操作 ＞﹏＜")
-        if raw_cmd.split(' ')[1] == '-all':
-            for c in global_chat_dict.values():
-                c.toggle_chat(enabled=True)
-        await identity.finish("已开启所有会话! <(￣▽￣)>")
-
-    elif raw_cmd in ["关闭", "off"]:
-        # if event.sender.role == 'member' and str(event.user_id) not in config.ADMIN_USERID:
-        #     await identity.finish("对不起！你没有权限进行此操作 ＞﹏＜")
-        chat.toggle_chat(enabled=False)
-        await identity.finish("已停止会话! <(＿　＿)>")
-
-    elif (raw_cmd.split(' ')[0] in ["关闭", "off"]) and len(raw_cmd.split(' ')) == 2:
-        # if str(event.user_id) not in config.ADMIN_USERID:
-        #     await identity.finish("对不起！你没有权限进行此操作 ＞﹏＜")
-        if raw_cmd.split(' ')[1] == '-all':
-            for c in global_chat_dict.values():
-                c.toggle_chat(enabled=False)
-        await identity.finish("已停止所有会话! <(＿　＿)>")
-
-    elif (raw_cmd.split(' ')[0] in ["重置", "reset"]) and len(raw_cmd.split(' ')) == 2:
-        # if event.sender.role == 'member' and str(event.user_id) not in config.ADMIN_USERID:
-        #     await identity.finish("对不起！你没有权限进行此操作 ＞﹏＜")
-        target_preset_key = raw_cmd.split(' ')[1]
-        if target_preset_key == '-all': # 重置所有预设
-            chat.reset_all_chat_preset()
-            await identity.finish("已重置当前会话所有预设! <(￣▽￣)>")
-        elif target_preset_key not in chat_presets_dict:
-            await identity.finish("找不到匹配的人格预设! 是不是手滑了呢？(；′⌒`)")
-        else:
-            chat.reset_chat_preset(target_preset_key)
-        await identity.finish(f"已重置当前会话预设: {target_preset_key}! <(￣▽￣)>")
-
-    elif raw_cmd.split(' ')[0] == "debug":
-        # if str(event.user_id) not in config.ADMIN_USERID:
-        #     await identity.finish("对不起！你没有权限进行此操作 ＞﹏＜")
-        debug_cmd = raw_cmd.split(' ')[1]
-        if debug_cmd == 'show':
-            await identity.finish(str(global_chat_dict))
-        elif debug_cmd == 'run':
-            await identity.finish(str(exec(raw_cmd.split(' ', 2)[2])))
-
-    elif raw_cmd in ["会话", "chats"]:
-        # if str(event.user_id) not in config.ADMIN_USERID:
-        #     await identity.finish("对不起！你没有权限进行此操作 ＞﹏＜")
-        chat_info = ''
-        for chat in global_chat_dict.values():
-            chat_info += f"+ {chat.generate_description()}"
-        await identity.finish((f"当前已加载的会话:\n{chat_info}"))
-
-    elif raw_cmd in ["记忆", "memory"] and len(raw_cmd.split(' ')) == 1:
-        # 检查主动记忆扩展模块和主动记忆功能是否启用
-        if not (global_extensions.get('remember') and global_extensions.get('forget') and config.MEMORY_ACTIVE):
-            logger.warning("记忆扩展模块未启用或主动记忆功能未开启！")
-        # 检查权限
-        # if str(event.user_id) not in config.ADMIN_USERID:
-        #     await identity.finish("对不起！你没有权限进行此操作 ＞﹏＜")
-        # 生成记忆信息
-        memory_info = ''
-        for k, v in chat.chat_preset.chat_memory.items():
-            memory_info += f"+ {k}: {v}\n"
-        if memory_info == '':
-            memory_info = "当前的记忆是空的呢 >﹏<"
-        command_instructions = (
-            f"=======================\n"
-            f"+ 编辑记忆: rg <记忆/memory> <edit> '<记忆键>' '<记忆值>'\n"
-        )
-        await identity.finish((f"当前人格记忆:\n{memory_info.split()}\n\n{command_instructions}"))
-
-    elif raw_cmd in ["记忆", "memory"] and len(raw_cmd.split(' ')) == 2:
-        # 检查主动记忆扩展模块和主动记忆功能是否启用
-        if not (global_extensions.get('remember') and global_extensions.get('forget') and config.MEMORY_ACTIVE):
-            logger.warning("记忆扩展模块未启用或主动记忆功能未开启！")
-        # 检查权限
-        # if str(event.user_id) not in config.ADMIN_USERID:
-        #     await identity.finish("对不起！你没有权限进行此操作 ＞﹏＜")
-
-    elif raw_cmd.split(' ')[0] in ["记忆", "memory"] and len(raw_cmd.split(' ')) >= 3:
-        # 检查主动记忆扩展模块和主动记忆功能是否启用
-        if not (global_extensions.get('remember') and global_extensions.get('forget') and config.MEMORY_ACTIVE):
-            logger.warning("记忆扩展模块未启用或主动记忆功能未开启！")
-        # 检查权限
-        # if str(event.user_id) not in config.ADMIN_USERID:
-        #     await identity.finish("对不起！你没有权限进行此操作 ＞﹏＜")
-        # 检查是否存在记忆
-        # 检查操作
-        if raw_cmd.split(' ')[1] in ["删除", "del", "delete"]:
-            # 检查是否存在记忆
-            if raw_cmd.split(' ', 2)[2] not in chat.chat_preset.chat_memory:
-                await identity.finish(f"找不到记忆: {raw_cmd.split(' ', 2)[2]}")
-            chat.set_memory(raw_cmd.split(' ', 2)[2], None)
-            await identity.finish(f"已删除记忆: {raw_cmd.split(' ', 2)[2]}")
-        elif raw_cmd.split(' ')[0] in ["记忆", "memory"] and len(raw_cmd.split(' ')) == 4:
-            # 检查主动记忆扩展模块和主动记忆功能是否启用
-            if not (global_extensions.get('remember') and global_extensions.get('forget') and config.MEMORY_ACTIVE):
-                logger.warning("记忆扩展模块未启用或主动记忆功能未开启！")
-            # 检查权限
-            # if str(event.user_id) not in config.ADMIN_USERID:
-            #     await identity.finish("对不起！你没有权限进行此操作 ＞﹏＜")
-            # 检查操作
-            if raw_cmd.split(' ')[1] in ["编辑", "edit", "update", "set"]:
-                chat.set_memory(raw_cmd.split(' ')[2], raw_cmd.split(' ')[3])
-                await identity.finish(f"编辑记忆: {raw_cmd.split(' ')[2]} 成功! (￣▽￣)")
-
-    else:
-        await identity.finish("输入的命令好像有点问题呢... 请检查下再试试吧！ ╮(>_<)╭")
-
-    if is_progress: # 如果有编辑进度，进行数据保存
-        # 更新所有全局预设到会话预设中
-        logger.info(f"用户: {event.get_user_id()} 进行了人格预设编辑: {raw_cmd}")
-        PersistentDataManager.instance.save_to_file()  # 保存数据
 
 """ ======== 消息响应方法 ======== """
 # 消息响应方法
@@ -507,6 +268,8 @@ async def do_msg_response(trigger_userid:str, trigger_text:str, is_tome:bool, ma
                 wake_up = True
                 break
 
+    current_preset_key = chat.get_chat_preset_key()
+
     # 判断是否需要回复
     if (    # 如果不是 bot 相关的信息，则直接返回
         wake_up or \
@@ -532,6 +295,10 @@ async def do_msg_response(trigger_userid:str, trigger_text:str, is_tome:bool, ma
     # 记录对用户的对话信息
     await chat.update_chat_history_row_for_user(sender=sender_name, msg=trigger_text, userid=trigger_userid, username=sender_name, require_summary=False)
 
+    if chat.get_chat_preset_key() != current_preset_key:
+        logger.warning(f'等待OpenAI请求返回的过程中人格预设由[{current_preset_key}]切换为[{chat.get_chat_preset_key()}],当前消息不再继续响应.1')
+        return
+    
     # 主动聊天参与逻辑 *待定方案
     # 达到一定兴趣阈值后，开始进行一次启动发言准备 收集特定条数的对话历史作为发言参考
     # 启动发言后，一段时间内兴趣值逐渐下降，如果随后被呼叫，则兴趣值提升
@@ -555,6 +322,7 @@ async def do_msg_response(trigger_userid:str, trigger_text:str, is_tome:bool, ma
             f.write(f"prompt 模板: \n{log_prompt_template}\n")
         logger.info(f"对话 prompt 模板已保存到日志文件: {chat_key}.{time.strftime('%Y-%m-%d %H-%M-%S')}.prompt.log")
 
+    time_before_request = time.time()
     tg = TextGenerator.instance
     raw_res, success = await tg.get_response(prompt=prompt_template, type='chat', custom={'bot_name': chat.get_chat_preset_key(), 'sender_name': sender_name})  # 生成对话结果
     if not success:  # 如果生成对话结果失败，则直接返回
@@ -564,9 +332,31 @@ async def do_msg_response(trigger_userid:str, trigger_text:str, is_tome:bool, ma
     # 输出对话原始响应结果
     if config.DEBUG_LEVEL > 0: logger.info(f"原始回应: {raw_res}")
 
+    if time.time() - time_before_request > config.OPENAI_TIMEOUT:
+        logger.warning(f'OpenAI响应超过timeout值[{config.OPENAI_TIMEOUT}]，停止处理')
+        return
+
+    if chat.get_chat_preset_key() != current_preset_key:
+        logger.warning(f'等待OpenAI响应返回的过程中人格预设由[{current_preset_key}]切换为[{chat.get_chat_preset_key()}],当前消息不再继续处理.2')
+        return
+
     # 用于存储最终回复顺序内容的列表
     reply_list = []
 
+    # 预检一次响应内容，如果响应内容中包含了需要打断的扩展调用指令，则直接截断原始响应中该扩展调用指令后的内容
+    pre_check_calls = re.findall(r"/#(.+?)#/", raw_res, re.S)
+    if pre_check_calls:
+        for call_str in pre_check_calls:
+            ext_name, *ext_args = call_str.split('&')
+            ext_name = ext_name.strip().lower()
+            if ext_name in global_extensions and global_extensions[ext_name].get_config().get('interrupt', False):
+                # 获取该扩展调用指令结束在原始响应中的位置
+                call_end_pos = raw_res.find(f"/#{call_str}#/") + len(f"/#{call_str}#/")
+                # 截断原始响应内容
+                raw_res = raw_res[:call_end_pos]
+                if config.DEBUG_LEVEL > 0: logger.warning(f"检测到需要打断的扩展调用指令: {call_str}, 已截断原始响应内容")
+                break
+
     # 提取markdown格式的代码块
     code_blocks = re.findall(r"```(.+?)```", raw_res, re.S)
     # 提取后去除所有markdown格式的代码块，剩余部分为对话结果
@@ -639,15 +429,19 @@ async def do_msg_response(trigger_userid:str, trigger_text:str, is_tome:bool, ma
         # 判断回复内容是否为str
         if isinstance(reply, str) and reply.strip():
             # 判断文本内容是否为纯符号(包括空格，换行、英文标点、中文标点)并且长度小于3
-            if re.match(r'^[^\u4e00-\u9fa5\w]{1,3}$', reply.strip()):
+            if re.match(r'^[^\u4e00-\u9fa5\w]{1}$', reply.strip()):
                 if config.DEBUG_LEVEL > 0: logger.info(f"检测到纯符号文本: {reply.strip()}，跳过发送...")
                 continue
-            await matcher.send(reply.strip())
+            if config.ENABLE_MSG_TO_IMG:
+                img = await text_to_img(reply.strip())
+                await matcher.send(MessageSegment.image(img))
+            else:
+                await matcher.send(reply.strip())
         else:
             for key in reply:   # 遍历回复内容类型字典
                 if key == 'text' and reply.get(key) and reply.get(key).strip(): # 发送文本
-                    # 判断文本内容是否为纯符号(包括空格，换行、英文标点、中文标点)并且长度小于3
-                    if re.match(r'^[^\u4e00-\u9fa5\w]{1,3}$', reply.get(key).strip()):
+                    # 判断文本内容是否为纯符号(包括空格，换行、英文标点、中文标点)并且长度为1
+                    if re.match(r'^[^\u4e00-\u9fa5\w]{1}$', reply.get(key).strip()):
                         if config.DEBUG_LEVEL > 0: logger.info(f"检测到纯符号文本: {reply.get(key).strip()}，跳过发送...")
                         continue
                     await matcher.send(reply.get(key).strip())
@@ -678,6 +472,11 @@ async def do_msg_response(trigger_userid:str, trigger_text:str, is_tome:bool, ma
                 elif key == 'timer' and reply.get(key):  # 定时器
                     logger.info(f"设置定时器: {reply.get(key)}")
                     loop_data['timer'] = reply.get(key)
+                elif key == 'preset' and reply.get(key):  # 更新对话预设
+                    if PersistentDataManager.instance.update_preset(chat_key=chat.get_chat_key(), preset_key=chat.get_chat_preset_key(), bot_self_introl=reply.get(key)):
+                        logger.info(f"更新对话预设: {reply.get(key)} 成功")
+                    else:
+                        logger.warning(f"更新对话预设: {reply.get(key)} 失败")
 
                 res_times -= 1
                 if res_times < 1:  # 如果回复次数超过限制，则跳出循环
